summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/widgets/tqvbuttongroup.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/widgets/tqvbuttongroup.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/widgets/tqvbuttongroup.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/experimental/tqtinterface/qt4/src/widgets/tqvbuttongroup.cpp b/experimental/tqtinterface/qt4/src/widgets/tqvbuttongroup.cpp
index d7a44902b..01a807bb2 100644
--- a/experimental/tqtinterface/qt4/src/widgets/tqvbuttongroup.cpp
+++ b/experimental/tqtinterface/qt4/src/widgets/tqvbuttongroup.cpp
@@ -62,24 +62,24 @@
/*!
Constructs a vertical button group with no title.
- The \a tqparent and \a name arguments are passed on to the TQWidget
+ The \a parent and \a name arguments are passed on to the TQWidget
constructor.
*/
-TQVButtonGroup::TQVButtonGroup( TQWidget *tqparent, const char *name )
- : TQButtonGroup( 1, Qt::Horizontal /* sic! */, tqparent, name )
+TQVButtonGroup::TQVButtonGroup( TQWidget *parent, const char *name )
+ : TQButtonGroup( 1, Qt::Horizontal /* sic! */, parent, name )
{
}
/*!
Constructs a vertical button group with the title \a title.
- The \a tqparent and \a name arguments are passed on to the TQWidget
+ The \a parent and \a name arguments are passed on to the TQWidget
constructor.
*/
-TQVButtonGroup::TQVButtonGroup( const TQString &title, TQWidget *tqparent,
+TQVButtonGroup::TQVButtonGroup( const TQString &title, TQWidget *parent,
const char *name )
- : TQButtonGroup( 1, Qt::Horizontal /* sic! */, title, tqparent, name )
+ : TQButtonGroup( 1, Qt::Horizontal /* sic! */, title, parent, name )
{
}